@@ -324,6 +324,26 @@ class InstalledApp:
     config: Dict[str, List[ConfigValue]]
     permissions: List[str] = field(factory=list)
 
+    def as_devices(self, key: str) -> List[DeviceValue]:
+        """Return a list of devices for a named configuration value."""
+        return [item.device_config for item in self.config[key]]  # type: ignore
+
+    def as_str(self, key: str) -> str:
+        """Return a named configuration value, interpreted as a string"""
+        return self.config[key][0].string_config.value  # type: ignore
+
+    def as_bool(self, key: str) -> bool:
+        """Return a named configuration value, interpreted as a boolean"""
+        return bool(self.as_str(key))
+
+    def as_int(self, key: str) -> int:
+        """Return a named configuration value, interpreted as an integer"""
+        return int(self.as_str(key))
+
+    def as_float(self, key: str) -> float:
+        """Return a named configuration value, interpreted as a float"""
+        return float(self.as_str(key))
+
 
 @frozen(kw_only=True)
 class Event:
@@ -420,6 +440,26 @@ class InstallData:
     refresh_token: str = field(repr=False)
     installed_app: InstalledApp
 
+    def as_devices(self, key: str) -> List[DeviceValue]:
+        """Return a list of devices for a named configuration value."""
+        return self.installed_app.as_devices(key)
+
+    def as_str(self, key: str) -> str:
+        """Return a named configuration value, interpreted as a string"""
+        return self.installed_app.as_str(key)
+
+    def as_bool(self, key: str) -> bool:
+        """Return a named configuration value, interpreted as a boolean"""
+        return self.installed_app.as_bool(key)
+
+    def as_int(self, key: str) -> int:
+        """Return a named configuration value, interpreted as an integer"""
+        return self.installed_app.as_int(key)
+
+    def as_float(self, key: str) -> float:
+        """Return a named configuration value, interpreted as a float"""
+        return self.installed_app.as_float(key)
+
 
 @frozen(kw_only=True)
 class UpdateData:
