@@ -8,12 +8,17 @@ import os
 from typing import Dict
 
 
-def load_data(path: str) -> Dict[str, str]:
+def load_file(path: str) -> str:
+    """Load text of a single file as a string."""
+    with open(path, encoding="utf-8") as r:
+        return r.read()
+
+
+def load_dir(path: str) -> Dict[str, str]:
     """Load text of all files in a directory into a dict."""
     data = {}
     for f in os.listdir(path):
         p = os.path.join(path, f)
         if os.path.isfile(p):
-            with open(p, encoding="utf-8") as r:
-                data[f] = r.read()
+            data[f] = load_file(p)
     return data
